==> jupyterlab_email-0.2.1.tar.gz: package/lib/index.d.ts <==
import { ILayoutRestorer, JupyterFrontEnd, JupyterFrontEndPlugin } from "@jupyterlab/application";
import { ICommandPalette } from "@jupyterlab/apputils";
import { IDocumentManager } from "@jupyterlab/docmanager";
import { IFileBrowserFactory } from "@jupyterlab/filebrowser";
import { ILauncher } from "@jupyterlab/launcher";
import { IMainMenu } from "@jupyterlab/mainmenu";
import { Widget } from "@lumino/widgets";
import "../style/index.css";
declare const extension: JupyterFrontEndPlugin<void>;
export declare class SendEmailWidget extends Widget {
    constructor(accounts?: string[], hide_code?: boolean, account_name?: string, templates?: string[], signatures?: string[], headers?: string[], footers?: string[]);
    getCode(): string;
    getEmail(): string;
    getType(): string;
    getTo(): string;
    getSubject(): string;
    getAlsoAttach(): string;
    getTemplate(): string;
    getSignature(): string;
    getHeader(): string;
    getFooter(): string;
    get typeNode(): HTMLSelectElement;
    get codeNode(): HTMLSelectElement;
    get emailNode(): HTMLSelectElement;
    get toNode(): HTMLTextAreaElement;
    get subjectNode(): HTMLTextAreaElement;
    get alsoAttachNode(): HTMLSelectElement;
    get templateNode(): HTMLSelectElement;
    get signatureNode(): HTMLSelectElement;
    get headerNode(): HTMLSelectElement;
    get footerNode(): HTMLSelectElement;
}
declare function activate(app: JupyterFrontEnd, docManager: IDocumentManager, palette: ICommandPalette, restorer: ILayoutRestorer, mainMenu: IMainMenu, browser: IFileBrowserFactory, launcher: ILauncher | null): void;
export default extension;
export { activate as _activate };

==> jupyterlab_email-0.2.3.tar.gz: package/lib/index.d.ts <==
import { ILayoutRestorer, JupyterFrontEnd, JupyterFrontEndPlugin } from "@jupyterlab/application";
import { ICommandPalette } from "@jupyterlab/apputils";
import { IDocumentManager } from "@jupyterlab/docmanager";
import { IFileBrowserFactory } from "@jupyterlab/filebrowser";
import { ILauncher } from "@jupyterlab/launcher";
import { IMainMenu } from "@jupyterlab/mainmenu";
import { Widget } from "@lumino/widgets";
import "../style/index.css";
declare const extension: JupyterFrontEndPlugin<void>;
export declare class SendEmailWidget extends Widget {
    constructor(accounts?: string[], hide_code?: boolean, account_name?: string, templates?: string[], signatures?: string[], headers?: string[], footers?: string[], user_templates?: string[], postprocessors?: string[]);
    getCode(): string;
    getEmail(): string;
    getType(): string;
    getTo(): string;
    getSubject(): string;
    getAlsoAttach(): string;
    getTemplate(): string;
    getSignature(): string;
    getHeader(): string;
    getFooter(): string;
    getUserTemplate(): string;
    getPostprocessor(): string;
    get typeNode(): HTMLSelectElement;
    get codeNode(): HTMLSelectElement;
    get emailNode(): HTMLSelectElement;
    get toNode(): HTMLTextAreaElement;
    get subjectNode(): HTMLTextAreaElement;
    get alsoAttachNode(): HTMLSelectElement;
    get templateNode(): HTMLSelectElement;
    get signatureNode(): HTMLSelectElement;
    get headerNode(): HTMLSelectElement;
    get footerNode(): HTMLSelectElement;
    get userTemplateNode(): HTMLSelectElement;
    get postprocessorNode(): HTMLSelectElement;
}
declare function activate(app: JupyterFrontEnd, docManager: IDocumentManager, palette: ICommandPalette, restorer: ILayoutRestorer, mainMenu: IMainMenu, browser: IFileBrowserFactory, launcher: ILauncher | null): void;
export default extension;
export { activate as _activate };
